@@ -14,12 +14,6 @@ extern "C" {
 
 R_LIB_VERSION_HEADER (r_bin);
 
-#define R_BIN_SCN_EXECUTABLE (1 << 0)
-#define R_BIN_SCN_WRITABLE   (1 << 1)
-#define R_BIN_SCN_READABLE   (1 << 2)
-#define R_BIN_SCN_SHAREABLE  (1 << 3)
-#define R_BIN_SCN_MAP        (1 << 4)
-
 #define R_BIN_DBG_STRIPPED 0x01
 #define R_BIN_DBG_STATIC   0x02
 #define R_BIN_DBG_LINENUMS 0x04
@@ -31,6 +25,7 @@ R_LIB_VERSION_HEADER (r_bin);
 #define R_BIN_ENTRY_TYPE_INIT    2
 #define R_BIN_ENTRY_TYPE_FINI    3
 #define R_BIN_ENTRY_TYPE_TLS     4
+#define R_BIN_ENTRY_TYPE_PREINIT 5
 
 #define R_BIN_SIZEOF_STRINGS 512
 #define R_BIN_MAX_ARCH 1024
@@ -65,6 +60,8 @@ R_LIB_VERSION_HEADER (r_bin);
 #define R_BIN_REQ_HEADER    0x2000000
 #define R_BIN_REQ_LISTPLUGINS 0x4000000
 #define R_BIN_REQ_RESOURCES 0x8000000
+#define R_BIN_REQ_INITFINI 0x10000000
+#define R_BIN_REQ_SEGMENTS 0x20000000
 
 /* RBinSymbol->method_flags : */
 #define R_BIN_METH_CLASS 0x0000000000000001L
@@ -90,6 +87,31 @@ R_LIB_VERSION_HEADER (r_bin);
 #define R_BIN_METH_CONSTRUCTOR 0x0000000000100000L
 #define R_BIN_METH_DECLARED_SYNCHRONIZED 0x0000000000200000L
 
+#define R_BIN_BIND_LOCAL_STR "LOCAL"
+#define R_BIN_BIND_GLOBAL_STR "GLOBAL"
+#define R_BIN_BIND_WEAK_STR "WEAK"
+#define R_BIN_BIND_NUM_STR "NUM"
+#define R_BIN_BIND_LOOS_STR "LOOS"
+#define R_BIN_BIND_HIOS_STR "HIOS"
+#define R_BIN_BIND_LOPROC_STR "LOPROC"
+#define R_BIN_BIND_HIPROC_STR "HIPROC"
+#define R_BIN_BIND_UNKNOWN_STR "UNKNOWN"
+
+#define R_BIN_TYPE_NOTYPE_STR "NOTYPE"
+#define R_BIN_TYPE_OBJECT_STR "OBJ"
+#define R_BIN_TYPE_FUNC_STR "FUNC"
+#define R_BIN_TYPE_METH_STR "METH"
+#define R_BIN_TYPE_SECTION_STR "SECT"
+#define R_BIN_TYPE_FILE_STR "FILE"
+#define R_BIN_TYPE_COMMON_STR "COMMON"
+#define R_BIN_TYPE_TLS_STR "TLS"
+#define R_BIN_TYPE_NUM_STR "NUM"
+#define R_BIN_TYPE_LOOS_STR "LOOS"
+#define R_BIN_TYPE_HIOS_STR "HIOS"
+#define R_BIN_TYPE_LOPROC_STR "LOPROC"
+#define R_BIN_TYPE_HIPROC_STR "HIPROC"
+#define R_BIN_TYPE_UNKNOWN_STR "UNK"
+
 enum {
 	R_BIN_SYM_ENTRY,
 	R_BIN_SYM_INIT,
@@ -135,10 +157,16 @@ enum {
 	R_BIN_RELOC_64 = 64
 };
 
+enum {
+	R_BIN_TYPE_DEFAULT = 0,
+	R_BIN_TYPE_CORE = 1
+};
+
 typedef struct r_bin_addr_t {
 	ut64 vaddr;
 	ut64 paddr;
-	ut64 haddr;
+	ut64 hvaddr;
+	ut64 hpaddr;
 	int type;
 	int bits;
 } RBinAddr;
@@ -171,6 +199,8 @@ typedef struct r_bin_info_t {
 	int has_va;
 	int has_pi; // pic/pie
 	int has_canary;
+	int has_retguard;
+	int has_sanitizers;
 	int has_crypto;
 	int has_nx;
 	int big_endian;
@@ -183,13 +213,6 @@ typedef struct r_bin_info_t {
 	RBinHash sum[3];
 	ut64 baddr;
 	char *intrp;
-#if 0
-// stored in sdb
-	/* crypto (iOS bins) */
-	int crypt_offset;
-	int crypt_size;
-	int crypt_enabled;
-#endif
 } RBinInfo;
 
 typedef struct r_bin_object_t {
@@ -210,22 +233,27 @@ typedef struct r_bin_object_t {
 	RList/*<??>*/ *strings;
 	RList/*<RBinClass>*/ *classes;
 	RList/*<RBinDwarfRow>*/ *lines;
+	HtUP *strings_db;
 	RList/*<??>*/ *mem;	//RBinMem maybe?
+	RList/*<BinMap*/ *maps;
+	char *regstate;
 	RBinInfo *info;
 	RBinAddr *binsym[R_BIN_SYM_LAST];
 	struct r_bin_plugin_t *plugin;
-	int referenced;
 	int lang;
 	Sdb *kv;
+	Sdb *addr2klassmethod;
 	void *bin_obj; // internal pointer used by formats
 } RBinObject;
 
-// XXX: this is a copy of RBinObject
+// XXX: RbinFile may hold more than one RBinObject
+/// XX curplugin == o->plugin
 typedef struct r_bin_file_t {
 	char *file;
 	int fd;
 	int size;
 	int rawstr;
+	int strmode;
 	ut32 id;
 	RBuffer *buf;
 	ut64 offset;
@@ -246,6 +274,15 @@ typedef struct r_bin_file_t {
 	struct r_bin_t *rbin;
 } RBinFile;
 
+typedef struct RBinFileOptions {
+	int rawstr;
+	ut64 baddr; // base address
+	ut64 laddr; // load address
+	ut64 paddr; // offset
+	const char *plugname; // force a plugin? why do i need this?
+	// const char *xtrname;
+} RBinFileOptions;
+
 typedef struct r_bin_t {
 	const char *file;
 	RBinFile *cur;
@@ -258,9 +295,10 @@ typedef struct r_bin_t {
 	ut64 maxstrbuf;
 	int rawstr;
 	Sdb *sdb;
-	RIDPool *file_ids;
+	RIDStorage *ids;
 	RList/*<RBinPlugin>*/ *plugins;
 	RList/*<RBinXtrPlugin>*/ *binxtrs;
+	RList/*<RBinLdrPlugin>*/ *binldrs;
 	RList/*<RBinFile>*/ *binfiles;
 	PrintfCallback cb_printf;
 	int loadany;
@@ -270,13 +308,14 @@ typedef struct r_bin_t {
 	bool want_dbginfo;
 	int filter; // symbol filtering
 	char strfilter; // string filtering
-	int strpurge; // purge false positive strings
+	char *strpurge; // purge false positive strings
 	char *srcdir; // dir.source
 	char *prefix; // bin.prefix
 	ut64 filter_rules;
 	bool demanglercmd;
 	bool verbose;
-	bool io_owned;
+	bool use_xtr; // use extract plugins when loading a file?
+	bool use_ldr; // use loader plugins when loading a file?
 } RBin;
 
 typedef struct r_bin_xtr_metadata_t {
@@ -285,6 +324,7 @@ typedef struct r_bin_xtr_metadata_t {
 	char *libname;
 	char *machine;
 	char *type;
+	const char *xtr_type;
 } RBinXtrMetadata;
 
 typedef int (*FREE_XTR)(void *xtr_obj);
@@ -300,13 +340,12 @@ typedef struct r_bin_xtr_extract_t {
 	RBinXtrMetadata *metadata;
 } RBinXtrData;
 
-R_API RBinXtrData * r_bin_xtrdata_new (RBuffer *buf, ut64 offset, ut64 size, ut32 file_count, RBinXtrMetadata *metadata);
-R_API void r_bin_xtrdata_free (void /*RBinXtrData*/ *data);
-R_API void r_bin_info_free (RBinInfo *rb);
+R_API RBinXtrData *r_bin_xtrdata_new(RBuffer *buf, ut64 offset, ut64 size, ut32 file_count, RBinXtrMetadata *metadata);
+R_API void r_bin_xtrdata_free(void /*RBinXtrData*/ *data);
+R_API void r_bin_info_free(RBinInfo *rb);
 R_API void r_bin_import_free(void *_imp);
 R_API void r_bin_symbol_free(void *_sym);
 R_API void r_bin_string_free(void *_str);
-// R_API void r_bin_field_free(void *_fld);
 
 typedef struct r_bin_xtr_plugin_t {
 	char *name;
@@ -314,18 +353,34 @@ typedef struct r_bin_xtr_plugin_t {
 	char *license;
 	int (*init)(void *user);
 	int (*fini)(void *user);
-// XXX: ut64 for size is maybe too much, what about st64? signed sizes are useful for detecting errors
+	// XXX: ut64 for size is maybe too much, what about st64? signed sizes are useful for detecting errors
 	bool (*check_bytes)(const ut8 *bytes, ut64 sz);
+
 	RBinXtrData * (*extract_from_bytes)(RBin *bin, const ut8 *buf, ut64 size, int idx);
 	RList * (*extractall_from_bytes)(RBin *bin, const ut8 *buf, ut64 size);
 	RBinXtrData * (*extract)(RBin *bin, int idx);
 	RList * (*extractall)(RBin *bin);
+
 	bool (*load)(RBin *bin);
 	int (*size)(RBin *bin);
 	int (*destroy)(RBin *bin);
 	int (*free_xtr)(void *xtr_obj);
 } RBinXtrPlugin;
 
+typedef struct r_bin_ldr_plugin_t {
+	char *name;
+	char *desc;
+	char *license;
+	int (*init)(void *user);
+	int (*fini)(void *user);
+	bool (*load)(RBin *bin);
+} RBinLdrPlugin;
+
+typedef struct r_bin_arch_options_t {
+	const char *arch;
+	int bits;
+} RBinArchOptions;
+
 typedef struct r_bin_plugin_t {
 	char *name;
 	char *desc;
@@ -336,7 +391,8 @@ typedef struct r_bin_plugin_t {
 	int (*fini)(void *user);
 	Sdb * (*get_sdb)(RBinFile *obj);
 	bool (*load)(RBinFile *arch);
-	void *(*load_bytes)(RBinFile *arch, const ut8 *buf, ut64 sz, ut64 loadaddr, Sdb *sdb);
+	bool (*load_bytes)(RBinFile *bf, void **bin_obj, const ut8 *buf, ut64 sz, ut64 loadaddr, Sdb *sdb);
+	void *(*load_buffer)(RBinFile *bf, RBuffer *buf, ut64 loadaddr, Sdb *sdb);
 	ut64 (*size)(RBinFile *bin); // return ut64 maybe? meh
 	int (*destroy)(RBinFile *arch);
 	bool (*check_bytes)(const ut8 *buf, ut64 length);
@@ -356,6 +412,7 @@ typedef struct r_bin_plugin_t {
 	RList/*<RBinClass>*/* (*classes)(RBinFile *arch);
 	RList/*<RBinMem>*/* (*mem)(RBinFile *arch);
 	RList/*<RBinReloc>*/* (*patch_relocs)(RBin *bin);
+	RList/*<RBinMap>*/* (*maps)(RBinFile *arch);
 	void (*header)(RBinFile *arch);
 	char* (*signature)(RBinFile *arch, bool json);
 	int (*demangle_type)(const char *str);
@@ -364,21 +421,25 @@ typedef struct r_bin_plugin_t {
 	int (*get_offset)(RBinFile *arch, int type, int idx);
 	char* (*get_name)(RBinFile *arch, int type, int idx);
 	ut64 (*get_vaddr)(RBinFile *arch, ut64 baddr, ut64 paddr, ut64 vaddr);
-	RBuffer* (*create)(RBin *bin, const ut8 *code, int codelen, const ut8 *data, int datalen);
+	RBuffer* (*create)(RBin *bin, const ut8 *code, int codelen, const ut8 *data, int datalen, RBinArchOptions *opt);
 	char* (*demangle)(const char *str);
+	char* (*regstate)(RBinFile *arch);
+	int (*file_type)(RBinFile *arch);
 	/* default value if not specified by user */
 	int minstrlen;
 	char strfilter;
 	void *user;
 } RBinPlugin;
 
+typedef void (*RBinSymbollCallback)(RBinObject *obj, void *symbol);
+
 typedef struct r_bin_section_t {
-	char name[R_BIN_SIZEOF_STRINGS + 1]; // TODO: must be char*
+	char *name;
 	ut64 size;
 	ut64 vsize;
 	ut64 vaddr;
 	ut64 paddr;
-	ut32 srwx;
+	ut32 perm;
 	// per section platform info
 	const char *arch;
 	char *format;
@@ -386,6 +447,7 @@ typedef struct r_bin_section_t {
 	bool has_strings;
 	bool add; // indicates when you want to add the section to io `S` command
 	bool is_data;
+	bool is_segment;
 } RBinSection;
 
 typedef struct r_bin_class_t {
@@ -402,9 +464,16 @@ typedef struct r_bin_class_t {
 
 #define RBinSectionName r_offsetof(RBinSection, name)
 #define RBinSectionOffset r_offsetof(RBinSection, offset)
-// usage:
-// r_list_get_by_name(bin->sections, RBinSectionName, ".text");
-// bin.sections.get_by_name(SectionName, ".text");
+
+#define REBASE_PADDR(o, l, type_t)\
+	do { \
+		RListIter *_it;\
+		type_t *_el;\
+		r_list_foreach ((l), _it, _el) { \
+			_el->paddr += (o)->loadaddr;\
+		}\
+	} while (0)
+
 
 typedef struct r_bin_symbol_t {
 	/* heap-allocated */
@@ -482,9 +551,9 @@ typedef struct r_bin_field_t {
 } RBinField;
 
 R_API RBinField *r_bin_field_new(ut64 paddr, ut64 vaddr, int size, const char *name, const char *comment, const char *format);
-R_API void r_bin_field_free(void *); //RBinField *field);
+R_API void r_bin_field_free(void *);
 
-typedef struct r_bin_mem_t {	//new toy for esil-init
+typedef struct r_bin_mem_t {
 	char *name;
 	ut64 addr;
 	int size;
@@ -492,6 +561,14 @@ typedef struct r_bin_mem_t {	//new toy for esil-init
 	RList *mirrors;		//for mirror access; stuff here should only create new maps not new fds
 } RBinMem;
 
+typedef struct r_bin_map_t {
+	ut64 addr;
+	ut64 offset;
+	int size;
+	int perms;
+	char *file;
+} RBinMap;
+
 typedef struct r_bin_dbginfo_t {
 	int (*get_line)(RBinFile *arch, ut64 addr, char *file, int len, int *line);
 } RBinDbgInfo;
@@ -523,123 +600,117 @@ typedef struct r_bin_bind_t {
 
 #ifdef R_API
 
-/* bin.c */
-R_API void r_bin_load_filter(RBin *bin, ut64 rules);
-R_API int r_bin_load(RBin *bin, const char *file, ut64 baseaddr, ut64 loadaddr, int xtr_idx, int fd, int rawstr);
-R_API int r_bin_reload(RBin *bin, int fd, ut64 baseaddr);
-R_API int r_bin_load_as(RBin *bin, const char *file, ut64 baseaddr, ut64 loadaddr, int xtr_idx, int fd, int rawstr, int fileoffset, const char *name);
-R_API int r_bin_load_io(RBin *bin, int fd, ut64 baseaddr, ut64 loadaddr, int xtr_idx);
-R_API bool r_bin_load_io_at_offset_as(RBin *bin, int fd, ut64 baseaddr, ut64 loadaddr, int xtr_idx, ut64 offset, const char *name);
-R_API int r_bin_load_io_at_offset_as_sz(RBin *bin, int fd, ut64 baseaddr, ut64 loadaddr, int xtr_idx, ut64 offset, const char *name, ut64 sz);
-R_API void r_bin_bind(RBin *b, RBinBind *bnd);
-R_API int r_bin_add(RBin *bin, RBinPlugin *foo);
-R_API int r_bin_xtr_add(RBin *bin, RBinXtrPlugin *foo);
-R_API void* r_bin_free(RBin *bin);
-R_API int r_bin_load_languages(RBinFile *binfile);
-R_API int r_bin_dump_strings(RBinFile *a, int min);
-R_API RList* r_bin_raw_strings(RBinFile *a, int min);
-//io-wrappers
-R_API int r_bin_read_at (RBin *bin, ut64 addr, ut8 *buf, int size);
-R_API int r_bin_write_at (RBin *bin, ut64 addr, const ut8 *buf, int size);
+typedef struct r_bin_options_t {
+	const char *pluginname;
+	ut64 offset; // starting physical address to read from the target file
+	ut64 baseaddr; // where the linker maps the binary in memory
+	ut64 loadaddr; // the desired offset where the binary should be loaded
+	ut64 sz;
+	int xtr_idx; // load Nth binary
+	int rawstr;
+	int fd;
+} RBinOptions;
 
-// ref
-R_API int r_bin_file_deref_by_bind (RBinBind * binb);
-R_API int r_bin_file_deref (RBin *bin, RBinFile * a);
-R_API int r_bin_file_ref_by_bind (RBinBind * binb);
-R_API int r_bin_file_ref (RBin *bin, RBinFile * a);
-R_API bool r_bin_file_object_new_from_xtr_data(RBin *bin, RBinFile *bf,
-						ut64 baseaddr, ut64 loadaddr,
-						RBinXtrData *xtr_data);
+R_API RBinImport *r_bin_import_clone(RBinImport *o);
+R_API RBinSymbol *r_bin_symbol_clone(RBinSymbol *o);
+typedef void (*RBinSymbolCallback)(RBinObject *obj, RBinSymbol *symbol);
+
+// options functions
+R_API void r_bin_options_init(RBinOptions *opt, int fd, ut64 baseaddr, ut64 loadaddr, int rawstr);
+R_API void r_bin_arch_options_init(RBinArchOptions *opt, const char *arch, int bits);
+
+// open/close/reload functions
+R_API RBin *r_bin_new(void);
+R_API void *r_bin_free(RBin *bin);
+R_API bool r_bin_open(RBin *bin, const char *file, RBinOptions *opt);
+R_API bool r_bin_open_io(RBin *bin, RBinOptions *opt);
+R_API int r_bin_reload(RBin *bin, int fd, ut64 baseaddr);
+
+// plugins/bind functions
+R_API void r_bin_bind(RBin *b, RBinBind *bnd);
+R_API bool r_bin_add(RBin *bin, RBinPlugin *foo);
+R_API bool r_bin_xtr_add(RBin *bin, RBinXtrPlugin *foo);
+R_API bool r_bin_ldr_add(RBin *bin, RBinLdrPlugin *foo);
 R_API int r_bin_list(RBin *bin, int json);
-R_API int r_bin_list_plugin(RBin *bin, const char* name, int json);
-R_API RBinObject *r_bin_get_object(RBin *bin);
-R_API ut64 r_binfile_get_baddr (RBinFile *binfile);
+R_API int r_bin_list_plugin(RBin *bin, const char *name, int json);
+R_API RBinPlugin *r_bin_file_cur_plugin(RBinFile *binfile);
+R_API RBinPlugin *r_bin_get_binplugin_by_bytes(RBin *bin, const ut8 *bytes, ut64 sz);
+R_API void r_bin_force_plugin(RBin *bin, const char *pname);
+
+// get/set various bin information
+R_API void r_bin_set_user_ptr(RBin *bin, void *user);
+R_API RBinInfo *r_bin_get_info(RBin *bin);
 R_API ut64 r_bin_get_baddr(RBin *bin);
 R_API void r_bin_set_baddr(RBin *bin, ut64 baddr);
 R_API ut64 r_bin_get_laddr(RBin *bin);
-R_API ut64 r_bin_get_boffset(RBin *bin);
-R_API RBinAddr* r_bin_get_sym(RBin *bin, int sym);
+R_API ut64 r_bin_get_size(RBin *bin);
+R_API RBinAddr *r_bin_get_sym(RBin *bin, int sym);
+R_API RList *r_bin_raw_strings(RBinFile *a, int min);
+R_API RList *r_bin_dump_strings(RBinFile *a, int min, int raw);
+R_API RList *r_bin_get_entries(RBin *bin);
+R_API RList *r_bin_get_fields(RBin *bin);
+R_API RList *r_bin_get_imports(RBin *bin);
+R_API RList *r_bin_get_libs(RBin *bin);
+R_API RList *r_bin_patch_relocs(RBin *bin);
+R_API RList *r_bin_get_relocs(RBin *bin);
+R_API RList *r_bin_get_sections(RBin *bin);
+R_API RList *r_bin_get_classes(RBin *bin);
+R_API RList *r_bin_get_strings(RBin *bin);
+R_API RList *r_bin_get_symbols(RBin *bin);
+R_API RList *r_bin_reset_strings(RBin *bin);
+R_API int r_bin_is_string(RBin *bin, ut64 va);
+R_API int r_bin_is_big_endian(RBin *bin);
+R_API int r_bin_is_static(RBin *bin);
+R_API ut64 r_bin_get_vaddr(RBin *bin, ut64 paddr, ut64 vaddr);
+R_API ut64 r_bin_a2b(RBin *bin, ut64 addr);
+
+R_API int r_bin_load_languages(RBinFile *binfile);
+R_API RBinFile *r_bin_cur(RBin *bin);
+R_API RBinObject *r_bin_cur_object(RBin *bin);
+
+// select/list binfiles functions
+R_API int r_bin_select(RBin *bin, const char *arch, int bits, const char *name);
+R_API int r_bin_select_by_ids(RBin *bin, ut32 binfile_id, ut32 binobj_id);
+R_API int r_bin_use_arch(RBin *bin, const char *arch, int bits, const char *name);
+R_API void r_bin_list_archs(RBin *bin, int mode);
+R_API RBuffer *r_bin_create(RBin *bin, const char *plugin_name, const ut8 *code, int codelen, const ut8 *data, int datalen, RBinArchOptions *opt);
+R_API RBuffer *r_bin_package(RBin *bin, const char *type, const char *file, RList *files);
+
+R_API const char *r_bin_string_type(int type);
 R_API const char *r_bin_entry_type_string(int etype);
 
-R_API char* r_bin_demangle(RBinFile *binfile, const char *lang, const char *str, ut64 vaddr);
-R_API int r_bin_demangle_type (const char *str);
+// binfile functions
+R_API bool r_bin_file_object_new_from_xtr_data(RBin *bin, RBinFile *bf, ut64 baseaddr, ut64 loadaddr, RBinXtrData *data);
+R_API RBinFile *r_bin_file_find_by_arch_bits(RBin *bin, const char *arch, int bits);
+R_API RBinFile *r_bin_file_find_by_fd(RBin *bin, ut32 bin_fd);
+R_API RBinFile *r_bin_file_find_by_name(RBin *bin, const char *name);
+R_API bool r_bin_file_set_cur_binfile(RBin *bin, RBinFile *bf);
+R_API bool r_bin_file_set_cur_by_name(RBin *bin, const char *name);
+R_API void r_bin_file_free(void /*RBinFile*/ *bf_);
+R_API bool r_bin_file_deref(RBin *bin, RBinFile *a);
+R_API bool r_bin_file_set_cur_by_fd(RBin *bin, ut32 bin_fd);
+R_API bool r_bin_file_close(RBin *bin, int bd);
+R_API int r_bin_file_delete_all(RBin *bin);
+R_API int r_bin_file_delete(RBin *bin, ut32 bin_fd);
+
+// binobject functions
+R_API int r_bin_object_set_items(RBinFile *binfile, RBinObject *o);
+R_API bool r_bin_object_delete(RBin *bin, ut32 binfile_id, ut32 binobj_id);
+
+// demangle functions
+R_API char *r_bin_demangle(RBinFile *binfile, const char *lang, const char *str, ut64 vaddr);
 R_API char *r_bin_demangle_java(const char *str);
 R_API char *r_bin_demangle_cxx(RBinFile *binfile, const char *str, ut64 vaddr);
 R_API char *r_bin_demangle_msvc(const char *str);
 R_API char *r_bin_demangle_swift(const char *s, bool syscmd);
 R_API char *r_bin_demangle_objc(RBinFile *binfile, const char *sym);
 R_API char *r_bin_demangle_rust(RBinFile *binfile, const char *str, ut64 vaddr);
-R_API int r_bin_lang_type(RBinFile *binfile, const char *def, const char *sym);
-R_API bool r_bin_lang_objc(RBinFile *binfile);
-R_API bool r_bin_lang_swift(RBinFile *binfile);
-R_API bool r_bin_lang_cxx(RBinFile *binfile);
-R_API bool r_bin_lang_msvc(RBinFile *binfile);
-R_API bool r_bin_lang_dlang(RBinFile *binfile);
-R_API bool r_bin_lang_rust(RBinFile *binfile);
+R_API int r_bin_demangle_type(const char *str);
+R_API void r_bin_demangle_list(RBin *bin);
+R_API char *r_bin_demangle_plugin(RBin *bin, const char *name, const char *str);
 R_API const char *r_bin_get_meth_flag_string(ut64 flag, bool compact);
 
-R_API RList* r_bin_get_entries(RBin *bin);
-R_API RList* r_bin_get_fields(RBin *bin);
-R_API RList* r_bin_get_imports(RBin *bin);
-R_API RBinInfo* r_bin_get_info(RBin *bin);
-R_API RList* r_bin_get_libs(RBin *bin);
-R_API ut64 r_bin_get_size (RBin *bin);
-R_API RList* r_bin_patch_relocs(RBin *bin);
-R_API RList* r_bin_get_relocs(RBin *bin);
-R_API RList* r_bin_get_sections(RBin *bin);
-R_API RList* /*<RBinClass>*/r_bin_get_classes(RBin *bin);
-
-R_API RBinClass *r_bin_class_get (RBinFile *binfile, const char *name);
-R_API RBinClass *r_bin_class_new (RBinFile *binfile, const char *name, const char *super, int view);
-R_API void r_bin_class_free(RBinClass *c);
-R_API RBinSymbol *r_bin_class_add_method (RBinFile *binfile, const char *classname, const char *name, int nargs);
-R_API void r_bin_class_add_field (RBinFile *binfile, const char *classname, const char *name);
-
-R_API RBinSection* r_bin_get_section_at(RBinObject *o, ut64 off, int va);
-R_API RList* r_bin_get_strings(RBin *bin);
-R_API int r_bin_is_string(RBin *bin, ut64 va);
-R_API RList* r_bin_reset_strings(RBin *bin);
-R_API RList* r_bin_get_symbols(RBin *bin);
-R_API RBinSymbol *r_bin_get_symbol_at_vaddr(RBin *bin, ut64 addr);
-R_API RBinSymbol *r_bin_get_symbol_at_paddr(RBin *bin, ut64 addr);
-R_API int r_bin_is_big_endian(RBin *bin);
-R_API int r_bin_is_stripped(RBin *bin);
-R_API int r_bin_is_static(RBin *bin);
-R_API int r_bin_has_dbg_linenums(RBin *bin);
-R_API int r_bin_has_dbg_syms(RBin *bin);
-R_API int r_bin_has_dbg_relocs(RBin *bin);
-R_API RBin* r_bin_new(void);
-R_API void r_bin_iobind(RBin *bin, RIO *io);
-R_API RBinFile * r_bin_cur(RBin *bin);
-R_API RBinObject * r_bin_cur_object(RBin *bin);
-R_API int r_bin_file_set_cur_binfile_obj(RBin * bin, RBinFile *bf, RBinObject *obj);
-R_API int r_bin_io_load(RBin *bin, RIO *io, int fd, ut64 baseaddr, ut64 loadaddr, int dummy);
-
-R_API int r_bin_select(RBin *bin, const char *arch, int bits, const char *name);
-R_API int r_bin_select_idx(RBin *bin, const char *name, int idx);
-R_API int r_bin_select_by_ids(RBin *bin, ut32 binfile_id, ut32 binobj_id );
-R_API int r_bin_object_delete (RBin *bin, ut32 binfile_id, ut32 binobj_id);
-R_API int r_bin_object_set_items(RBinFile *binfile, RBinObject *o);
-R_API int r_bin_use_arch(RBin *bin, const char *arch, int bits, const char *name);
-R_API RBinFile * r_bin_file_find_by_arch_bits(RBin *bin, const char *arch, int bits, const char *name);
-R_API RBinObject * r_bin_object_find_by_arch_bits (RBinFile *binfile, const char *arch, int bits, const char *name);
-R_API void r_bin_list_archs(RBin *bin, int mode);
-R_API void r_bin_set_user_ptr(RBin *bin, void *user);
-R_API RBuffer *r_bin_create (RBin *bin, const ut8 *code, int codelen, const ut8 *data, int datalen);
-R_API RBuffer *r_bin_package (RBin *bin, const char *type, const char *file, RList *files);
-R_API ut64 r_bin_get_vaddr (RBin *bin, ut64 paddr, ut64 vaddr);
-R_API ut64 r_bin_a2b (RBin *bin, ut64 addr);
-R_API int r_bin_file_delete(RBin *bin, ut32 bin_fd);
-R_API int r_bin_file_delete_all(RBin *bin);
-R_API int r_bin_file_set_cur_by_fd (RBin *bin, ut32 bin_fd);
-R_API int r_bin_file_set_cur_by_name (RBin * bin, const char * name);
-R_API RBinFile * r_bin_file_find_by_fd (RBin *bin, ut32 bin_fd);
-R_API RBinFile * r_bin_file_find_by_name (RBin * bin, const char * name);
-R_API RBinFile * r_bin_file_find_by_name_n (RBin * bin, const char * name, int idx);
-R_API int r_bin_file_set_cur_binfile (RBin * bin, RBinFile *bf);
-R_API RBinPlugin * r_bin_file_cur_plugin (RBinFile *binfile);
-R_API void r_bin_force_plugin (RBin *bin, const char *pname);
-R_API const char *r_bin_string_type (int type);
+R_API RBinSection *r_bin_get_section_at(RBinObject *o, ut64 off, int va);
 
 /* dbginfo.c */
 R_API int r_bin_addr2line(RBin *bin, ut64 addr, char *file, int len, int *line);
@@ -657,18 +728,17 @@ R_API RList *r_bin_dwarf_parse_line(RBin *a, int mode);
 R_API RList *r_bin_dwarf_parse_aranges(RBin *a, int mode);
 R_API RBinDwarfDebugAbbrev *r_bin_dwarf_parse_abbrev(RBin *a, int mode);
 
-R_API RBinPlugin * r_bin_get_binplugin_by_bytes (RBin *bin, const ut8* bytes, ut64 sz);
-
-R_API void r_bin_demangle_list(RBin *bin);
-R_API char *r_bin_demangle_plugin(RBin *bin, const char *name, const char *str);
-
-R_API RList *r_bin_get_mem (RBin *bin);
+R_API RList *r_bin_get_mem(RBin *bin);
 
 /* filter.c */
-R_API void r_bin_filter_name(Sdb *db, ut64 addr, char *name, int maxlen);
-R_API void r_bin_filter_symbols (RList *list);
-R_API void r_bin_filter_sections (RList *list);
-R_API void r_bin_filter_classes (RList *list);
+R_API void r_bin_load_filter(RBin *bin, ut64 rules);
+R_API void r_bin_filter_symbols(RBinFile *bf, RList *list);
+R_API void r_bin_filter_sections(RBinFile *bf, RList *list);
+R_API char *r_bin_filter_name(RBinFile *bf, Sdb *db, ut64 addr, char *name);
+R_API void r_bin_filter_sym(RBinFile *bf, Sdb *db, ut64 vaddr, RBinSymbol *sym);
+R_API bool r_bin_strpurge(RBin *bin, const char *str, ut64 addr);
+R_API bool r_bin_string_filter(RBin *bin, const char *str, ut64 addr);
+R_API bool r_bin_is_cxx(RBinFile *binfile);
 
 /* plugin pointers */
 extern RBinPlugin r_bin_plugin_any;
@@ -684,11 +754,12 @@ extern RBinPlugin r_bin_plugin_pebble;
 extern RBinPlugin r_bin_plugin_bios;
 extern RBinPlugin r_bin_plugin_bf;
 extern RBinPlugin r_bin_plugin_te;
+extern RBinPlugin r_bin_plugin_symbols;
 extern RBinPlugin r_bin_plugin_mach0;
 extern RBinPlugin r_bin_plugin_mach064;
+extern RBinPlugin r_bin_plugin_mdmp;
 extern RBinPlugin r_bin_plugin_java;
 extern RBinPlugin r_bin_plugin_dex;
-extern RBinPlugin r_bin_plugin_dummy;
 extern RBinPlugin r_bin_plugin_coff;
 extern RBinPlugin r_bin_plugin_ningb;
 extern RBinPlugin r_bin_plugin_ningba;
@@ -696,8 +767,10 @@ extern RBinPlugin r_bin_plugin_ninds;
 extern RBinPlugin r_bin_plugin_nin3ds;
 extern RBinPlugin r_bin_plugin_xbe;
 extern RBinPlugin r_bin_plugin_bflt;
-extern RBinXtrPlugin r_bin_xtr_plugin_fatmach0;
+extern RBinXtrPlugin r_bin_xtr_plugin_xtr_fatmach0;
 extern RBinXtrPlugin r_bin_xtr_plugin_xtr_dyldcache;
+extern RBinXtrPlugin r_bin_xtr_plugin_xtr_pemixed; 
+extern RBinLdrPlugin r_bin_ldr_plugin_ldr_linux;
 extern RBinPlugin r_bin_plugin_zimg;
 extern RBinPlugin r_bin_plugin_omf;
 extern RBinPlugin r_bin_plugin_art;
@@ -715,7 +788,9 @@ extern RBinPlugin r_bin_plugin_avr;
 extern RBinPlugin r_bin_plugin_menuet;
 extern RBinPlugin r_bin_plugin_wasm;
 extern RBinPlugin r_bin_plugin_nro;
+extern RBinPlugin r_bin_plugin_nso;
 extern RBinPlugin r_bin_plugin_sfc;
+extern RBinPlugin r_bin_plugin_z64;
 
 #ifdef __cplusplus
 }
