@@ -6,9 +6,9 @@ extern "C" {
 #endif
 
 typedef enum {
-	PANEL_TYPE_FRAME = 0,
+	PANEL_TYPE_DEFAULT = 0,
 	PANEL_TYPE_MENU = 1
-} PanelType;
+} RPanelType;
 
 typedef struct r_panel_pos_t {
 	int x;
@@ -20,16 +20,16 @@ typedef struct r_panel_pos_t {
 typedef struct r_panel_t {
 	RPanelPos pos;
 	RPanelPos prevPos;
-	int depth;
 	int sx; // scroll-x
 	int sy; // scroll-y
 	int curpos;
 	char *cmd;
 	char *title;
 	bool refresh;
-	PanelType type;
+	RPanelType type;
 	ut64 baseAddr;
 	ut64 addr;
+	bool caching;
 	char *cmdStrCache;
 } RPanel;
 
